@@ -1,9 +1,8 @@
 import re
-from plumbum import colors
 
+from plumbum import colors
 from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QListWidget, QVBoxLayout, \
-    QDialog, QMessageBox
+from PyQt5.QtWidgets import QDialog, QListWidget, QMessageBox, QVBoxLayout
 from pyqtgraph import QtCore
 
 from linien.client.utils import connect_ssh
@@ -17,8 +16,10 @@ class SSHCommandOutputWidget(QListWidget):
         self.setSelectionMode(self.NoSelection)
 
     def execute(self, ssh, command):
-        self.stdin, self.stdout, self.stderr = ssh.exec_command(command, bufsize=0, get_pty=True)
-        self.addItem('>>> %s' % command)
+        self.stdin, self.stdout, self.stderr = ssh.exec_command(
+            command, bufsize=0, get_pty=True
+        )
+        self.addItem(">>> %s" % command)
         self.show_output()
 
     def show_output(self):
@@ -29,11 +30,11 @@ class SSHCommandOutputWidget(QListWidget):
                 toread = len(output.channel.in_buffer)
                 if toread == 0:
                     continue
-                buf = output.read(toread).decode('utf8').rstrip('\n')
+                buf = output.read(toread).decode("utf8").rstrip("\n")
 
-                for part in buf.split('\n'):
-                    for subpart_i, subpart in enumerate(part.split('\r')):
-                        subpart = subpart.strip('\n').strip('\r').strip('\r\n')
+                for part in buf.split("\n"):
+                    for subpart_i, subpart in enumerate(part.split("\r")):
+                        subpart = subpart.strip("\n").strip("\r").strip("\r\n")
                         if subpart:
                             print(
                                 (colors.red if output == self.stderr else colors.reset)
@@ -45,7 +46,9 @@ class SSHCommandOutputWidget(QListWidget):
 
                             self.addItem(
                                 # filter out special things like color codes etc.
-                                re.sub(r'\x1b(\[.*?[@-~]|\].*?(\x07|\x1b\\))', '', subpart)
+                                re.sub(
+                                    r"\x1b(\[.*?[@-~]|\].*?(\x07|\x1b\\))", "", subpart
+                                )
                             )
 
                 self.scrollToBottom()
@@ -53,12 +56,13 @@ class SSHCommandOutputWidget(QListWidget):
         QtCore.QTimer.singleShot(1000, self.show_output)
 
 
-def execute_command(parent, host, user, password, command, callback):
-    print((colors.bold | 'Execute command: ') + command)
+def execute_command_and_show_output(parent, host, user, password, command, callback):
+    print((colors.bold | "Execute command: ") + command)
 
     ssh = connect_ssh(host, user, password)
 
     window = QDialog(parent)
+    window.setWindowTitle("Installing Linien server component")
     window.resize(800, 600)
     window_layout = QVBoxLayout(window)
 
@@ -72,6 +76,7 @@ def execute_command(parent, host, user, password, command, callback):
     def after_command():
         window.hide()
         callback()
+
     widget.command_ended.connect(after_command)
 
     widget.execute(ssh, command)
@@ -86,8 +91,8 @@ class LoadingDialog(QMessageBox):
         super().__init__(parent)
 
         self.setIcon(QMessageBox.Information)
-        self.setText('Connecting to %s' % host)
-        self.setWindowTitle('Connecting')
+        self.setText("Connecting to %s" % host)
+        self.setWindowTitle("Connecting")
         self.setModal(True)
         self.setWindowModality(QtCore.Qt.WindowModal)
         self.setStandardButtons(QMessageBox.NoButton)
@@ -103,18 +108,28 @@ class LoadingDialog(QMessageBox):
 
 
 def error_dialog(parent, error):
-    return QMessageBox.question(
-        parent, 'Error', error,
-        QMessageBox.Ok,
-        QMessageBox.Ok
-    )
+    return QMessageBox.question(parent, "Error", error, QMessageBox.Ok, QMessageBox.Ok)
 
 
-def question_dialog(parent, question):
+def question_dialog(parent, question, title):
+    box = QMessageBox(parent)
+    box.setText(question)
+    box.setWindowTitle(title)
     reply = QMessageBox.question(
-        parent, 'Error', question,
-        QMessageBox.Yes | QMessageBox.No,
-        QMessageBox.Yes
+        parent, title, question, QMessageBox.Yes | QMessageBox.No, QMessageBox.Yes
     )
 
-    return reply == QMessageBox.Yes
\ No newline at end of file
+    return reply == QMessageBox.Yes
+
+
+def ask_for_parameter_restore_dialog(parent, question, title):
+    box = QMessageBox(parent)
+    box.setText(question)
+    box.setWindowTitle(title)
+    # do_nothing_button
+    _ = box.addButton("Keep remote parameters", QMessageBox.NoRole)
+    upload_button = box.addButton("Upload local parameters", QMessageBox.YesRole)
+
+    box.exec_()
+
+    return box.clickedButton() == upload_button
