@@ -1,32 +1,44 @@
-from PyQt5 import QtGui
+from PyQt5 import QtWidgets
+
 from linien.gui.widgets import CustomWidget
 
 
-class RightPanel(QtGui.QWidget, CustomWidget):
+class RightPanel(QtWidgets.QWidget, CustomWidget):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
     def connection_established(self):
-        self.control = self.app().control
-        self.parameters = self.app().parameters
+        self.parameters = self.app.parameters
+        self.control = self.app.control
 
         self.parameters.autolock_running.on_change(self.autolock_status_changed)
         self.parameters.optimization_running.on_change(self.optimization_status_changed)
         self.parameters.lock.on_change(self.enable_or_disable_panels)
 
+        def highlight_psd_button(locked):
+            self.ids.pid_parameter_optimization_button.setStyleSheet(
+                "background: #00aa00;" if locked else ""
+            )
+
+        self.parameters.lock.on_change(highlight_psd_button)
+
     def ready(self):
         self.ids.closeButton.clicked.connect(self.close_app)
         self.ids.shutdownButton.clicked.connect(self.shutdown_server)
         self.ids.openDeviceManagerButton.clicked.connect(self.open_device_manager)
+        self.ids.pid_parameter_optimization_button.clicked.connect(self.open_psd_window)
 
     def close_app(self):
-        self.app().close()
+        self.app.close()
 
     def shutdown_server(self):
-        self.app().shutdown()
+        self.app.shutdown()
+
+    def open_psd_window(self):
+        self.app.open_psd_window()
 
     def open_device_manager(self):
-        self.app().open_device_manager()
+        self.app.open_device_manager()
 
     def autolock_status_changed(self, value):
         if value:
@@ -49,12 +61,8 @@ class RightPanel(QtGui.QWidget, CustomWidget):
             for panel_name in panel_names:
                 getattr(self.ids, panel_name).setEnabled(condition)
 
+        enable_panels(("generalPanel",), not autolock and not optimization and not lock)
         enable_panels(
-            ('generalPanel',), not autolock and not optimization and not lock
+            ("modSpectroscopyPanel", "viewPanel", "lockingPanel"), not optimization
         )
-        enable_panels(
-            ('modSpectroscopyPanel', 'viewPanel', 'lockingPanel'), not optimization
-        )
-        enable_panels(
-            ('optimizationPanel',), not autolock and not lock
-        )
\ No newline at end of file
+        enable_panels(("optimizationPanel",), not autolock and not lock)
